==> zwap_design_system-0.1.353.tar.gz: lib/atoms/page/page.dart <==
/// IMPORTING THIRD PARTY PACKAGES
import 'package:flutter/material.dart';
import 'package:provider/provider.dart';
import 'package:zwap_utils/zwap_utils.dart';

/// Provider class to handle the different states inside this single page routing
class ZwapBasePageProviderState extends ChangeNotifier{

  /// The theme data for this single page routing
  final ThemeData zwapThemeData;

  /// The localization delegates class for this single page routing
  final Iterable<LocalizationsDelegate<dynamic>>? localizationsDelegate;

  /// The supported locales for this single page routing
  final Iterable<Locale> locales;

  /// The current local language for this single page routing
  final Locale? localLanguage;

  /// The current title for this single page routing
  final String title;

  /// The name-widget mapping for this single page routing
  final Map<String, Widget> layoutMapping;

  ZwapBasePageProviderState({
    required this.zwapThemeData,
    required this.localizationsDelegate,
    required this.locales,
    required this.localLanguage,
    required this.title,
    required this.layoutMapping
  });

  /// The current screen state
  String _currentScreenState = Utils.currentState.currentPath() ?? "/";

  /// The history of the visited pages
  List<String> _historyPages = [];

  /// Has the some screen in history
  bool hasScreenInHistory(String screenName) => this._historyPages.contains(screenName);

  /// It handles the change screen function
  void changeScreen(String newScreen, BuildContext context, Map<String, String> args){
    this._historyPages.add(newScreen);
    this._currentScreenState = newScreen;
    Utils.currentState.goToScreen(newScreen, context, args);
    notifyListeners();
  }

  /// It handles the go back screen function
  void goBack(BuildContext context){
    this._historyPages.removeLast();
    this._currentScreenState = this._historyPages.last;
    Utils.currentState.goBack(context);
    notifyListeners();
  }


}

/// Custom widget to handle the base single page routing
class ZwapBasePage extends StatelessWidget{

  Widget build(BuildContext context){
    ZwapBasePageProviderState provider = context.read<ZwapBasePageProviderState>();
    return MaterialApp(
      theme: provider.zwapThemeData,
      home: Consumer<ZwapBasePageProviderState>(
        builder: (context, mainProvider, child){
          return mainProvider.layoutMapping[mainProvider._currentScreenState]!;
        }
      ),
      debugShowCheckedModeBanner: false,
      title: provider.title,
      locale: provider.localLanguage,
      localizationsDelegates: provider.localizationsDelegate,
      supportedLocales: provider.locales,
    );
  }

}

==> zwap_design_system-0.1.354.tar.gz: lib/atoms/page/page.dart <==
/// IMPORTING THIRD PARTY PACKAGES
import 'package:flutter/material.dart';
import 'package:provider/provider.dart';
import 'package:zwap_utils/zwap_utils.dart';

/// Provider class to handle the different states inside this single page routing
class ZwapBasePageProviderState extends ChangeNotifier{

  /// The theme data for this single page routing
  final ThemeData zwapThemeData;

  /// The localization delegates class for this single page routing
  final Iterable<LocalizationsDelegate<dynamic>>? localizationsDelegate;

  /// The supported locales for this single page routing
  final Iterable<Locale> locales;

  /// The current local language for this single page routing
  final Locale? localLanguage;

  /// The current title for this single page routing
  final String title;

  /// It gets the correct widget in base of the current screen name
  final Widget Function(String screenName) layoutMapping;

  ZwapBasePageProviderState({
    required this.zwapThemeData,
    required this.localizationsDelegate,
    required this.locales,
    required this.localLanguage,
    required this.title,
    required this.layoutMapping
  });

  /// The current screen state
  String _currentScreenState = Utils.currentState.currentPath() ?? "/";

  /// The history of the visited pages
  List<String> _historyPages = [];

  /// Has the some screen in history
  bool hasScreenInHistory(String screenName) => this._historyPages.contains(screenName);

  /// It handles the change screen function
  void changeScreen(String newScreen, BuildContext context, Map<String, String> args){
    this._historyPages.add(newScreen);
    this._currentScreenState = newScreen;
    Utils.currentState.goToScreen(newScreen, context, args);
    notifyListeners();
  }

  /// It handles the go back screen function
  void goBack(BuildContext context){
    this._historyPages.removeLast();
    this._currentScreenState = this._historyPages.last;
    Utils.currentState.goBack(context);
    notifyListeners();
  }


}

/// Custom widget to handle the base single page routing
class ZwapBasePage extends StatelessWidget{

  Widget build(BuildContext context){
    ZwapBasePageProviderState provider = context.read<ZwapBasePageProviderState>();
    return MaterialApp(
      theme: provider.zwapThemeData,
      home: Consumer<ZwapBasePageProviderState>(
        builder: (context, mainProvider, child){
          return mainProvider.layoutMapping(mainProvider._currentScreenState);
        }
      ),
      debugShowCheckedModeBanner: false,
      title: provider.title,
      locale: provider.localLanguage,
      localizationsDelegates: provider.localizationsDelegate,
      supportedLocales: provider.locales,
    );
  }

}
